@@ -24,7 +24,11 @@
 #include <KIconLoader>
 #include <KLocalizedString>
 #include <KNotification>
+#include <KWindowInfo>
 #include <KWindowSystem>
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+#include <KX11Extras>
+#endif
 
 using namespace Amarok;
 
@@ -80,7 +84,11 @@ bool
 KNotificationBackend::isFullscreenWindowActive() const
 {
     // Get information of the active window.
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     KWindowInfo activeWindowInfo( KWindowSystem::activeWindow(), NET::WMState );
+#else
+    KWindowInfo activeWindowInfo( KX11Extras::activeWindow(), NET::WMState );
+#endif
 
     // Check if it is running in fullscreen mode.
     return activeWindowInfo.hasState( NET::FullScreen );
@@ -131,8 +139,8 @@ KNotificationBackend::showCurrentTrack( bool force )
     notify->setText( text );
     notify->setPixmap( pixmap );
 
-    if( m_notify ) // existing notification already shown
-        notify->update();
-    notify->sendEvent(); // (re)start timeout in both cases
+    // looking at KF 5.89 sources, setting properties and calling sendEvent seems to take care of any
+    // updating or creating new notifications, so a call to update() was removed here during Qt6 porting
+    notify->sendEvent();
     m_notify = notify;
 }
