@@ -17,33 +17,28 @@
 #include "ServiceBrowser.h"
 
 #include "core/support/Debug.h"
-#include "context/ContextView.h"
-#include "PaletteHandler.h"
-#include "widgets/PrettyTreeView.h"
-#include "browsers/InfoProxy.h"
 
-#include <KStandardDirs>
+#include <QStandardPaths>
 
-ServiceBrowser * ServiceBrowser::s_instance = 0;
+ServiceBrowser * ServiceBrowser::s_instance = nullptr;
 
 ServiceBrowser * ServiceBrowser::instance()
 {
-    if ( s_instance == 0 )
-        s_instance = new ServiceBrowser( 0, "internet" );
+    if ( s_instance == nullptr )
+        s_instance = new ServiceBrowser( QStringLiteral("internet") );
 
     return s_instance;
 }
 
 
-ServiceBrowser::ServiceBrowser( QWidget * parent, const QString& name )
-    : BrowserCategoryList( parent, name, true )
-    , m_usingContextView( false )
+ServiceBrowser::ServiceBrowser( const QString& name, QWidget* parent )
+    : BrowserCategoryList( name, parent, true )
 {
     debug() << "ServiceBrowser starting...";
 
     setLongDescription( i18n( "The Internet browser lets you browse online sources of content that integrates directly into Amarok. Amarok ships with a number of these sources, but many more can be added using scripts." ) );
 
-    setImagePath( KStandardDirs::locate( "data", "amarok/images/hover_info_internet.png" ) );
+    setImagePath( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/hover_info_internet.png") ) );
 }
 
 
@@ -58,7 +53,8 @@ ServiceBrowser::setScriptableServiceManager( ScriptableServiceManager * scriptab
 {
     m_scriptableServiceManager = scriptableServiceManager;
     m_scriptableServiceManager->setParent( this );
-    connect ( m_scriptableServiceManager, SIGNAL( addService ( ServiceBase * ) ), this, SLOT( addService (  ServiceBase * ) ) );
+    connect ( m_scriptableServiceManager, &ScriptableServiceManager::addService,
+              this, &ServiceBrowser::addService );
 }
 
 void
@@ -71,29 +67,10 @@ ServiceBrowser::resetService( const QString &name )
     Q_UNUSED( name );
 }
 
-QString ServiceBrowser::activeServiceFilter()
-{
-
-    ServiceBase * service = dynamic_cast<ServiceBase *>( activeCategory() );
-    if ( service )
-        return service->filter();
-    return QString();
-}
-
-QList<int> ServiceBrowser::activeServiceLevels()
-{
-
-    ServiceBase * service = dynamic_cast<ServiceBase *>( activeCategory() );
-    if ( service )
-        return service->levels();
-    return QList<int>();
-}
-
 void ServiceBrowser::addService( ServiceBase * service )
 {
     DEBUG_BLOCK
     addCategory( service );
 }
 
-#include "ServiceBrowser.moc"
 
