@@ -18,7 +18,6 @@
 
 #include "core/support/Debug.h"
 
-#include <QIcon>
 #include <QMutexLocker>
 
 #include <KLocalizedString>
@@ -218,7 +217,7 @@ int CompoundProgressBar::calcCompoundPercentage()
     int count = m_progressMap.count();
     int total = 0;
 
-    foreach( ProgressBar *currentBar, m_progressMap )
+    for( ProgressBar *currentBar : m_progressMap )
         total += currentBar->percentage();
 
     return count == 0 ? 0 : total / count;
@@ -228,7 +227,7 @@ void CompoundProgressBar::cancelAll()
 {
     QMutexLocker locker( &m_mutex );
 
-    foreach( ProgressBar *currentBar, m_progressMap )
+    for( ProgressBar *currentBar : m_progressMap )
         currentBar->cancel();
 }
 
