@@ -51,6 +51,7 @@
 #include <QPainter>
 #include <QPaintEvent>
 #include <QResizeEvent>
+#include <QRegularExpression>
 #include <QSlider>
 #include <QTimer>
 #include <QVBoxLayout>
@@ -78,7 +79,7 @@ MainToolbar::MainToolbar( QWidget *parent )
     , m_trackBarAnimationTimer( 0 )
 {
     DEBUG_BLOCK
-    setObjectName( "MainToolbar" );
+    setObjectName( QStringLiteral("MainToolbar") );
 
     m_promoString = i18n( "Rediscover Your Music" );
 
@@ -107,8 +108,8 @@ MainToolbar::MainToolbar( QWidget *parent )
         fnt.setPointSize( qRound(fnt.pointSize() * track_fontsize_factor) );
     const int fntH = QFontMetrics( QApplication::font() ).height()*2; //double size svg render for scaled high dpi
 
-    m_skip_left = The::svgHandler()->renderSvg( "tiny_skip_left", 80*fntH/128, fntH, "tiny_skip_left" );
-    m_skip_right = The::svgHandler()->renderSvg( "tiny_skip_right", 80*fntH/128, fntH, "tiny_skip_right" );
+    m_skip_left = The::svgHandler()->renderSvg( QStringLiteral("tiny_skip_left"), 80*fntH/128, fntH, QStringLiteral("tiny_skip_left") );
+    m_skip_right = The::svgHandler()->renderSvg( QStringLiteral("tiny_skip_right"), 80*fntH/128, fntH, QStringLiteral("tiny_skip_right") );
 
     m_prev.key = nullptr;
     m_prev.label = new AnimatedLabelStack(QStringList(), info);
@@ -131,7 +132,7 @@ MainToolbar::MainToolbar( QWidget *parent )
     m_current.label->setLayout( new QHBoxLayout );
     m_current.label->installEventFilter( this );
     connect( m_current.label, &AnimatedLabelStack::clicked,
-             Amarok::actionCollection()->action("show_active_track"), &QAction::trigger );
+             Amarok::actionCollection()->action(QStringLiteral("show_active_track")), &QAction::trigger );
 
     m_next.key = nullptr;
     m_next.label = new AnimatedLabelStack(QStringList(), info);
@@ -369,7 +370,7 @@ MainToolbar::updateCurrentTrackActions()
     // collect actions ================
     QList<QAction*> actions;
 
-    foreach( QAction* action, The::globalCurrentTrackActions()->actions() )
+    for( QAction* action : The::globalCurrentTrackActions()->actions() )
         actions << action;
 
     Meta::TrackPtr track = The::engineController()->currentTrack();
@@ -418,13 +419,13 @@ static QStringList metadata( Meta::TrackPtr track )
         if(( noTags = title.isEmpty() )) // should never happen
             title = track->playableUrl().url();
         if(( noTags = title.isEmpty() )) // sth's MEGA wrong ;-)
-            title = "???";
+            title = QStringLiteral("???");
 
         // no tags -> probably filename. try to strip the suffix
         if( noTags || track->name().isEmpty() )
         {
             noTags = true;
-            int dot = title.lastIndexOf('.');
+            int dot = title.lastIndexOf(QLatin1Char('.'));
             if( dot > 0 && title.length() - dot < 6 )
                 title = title.left( dot );
         }
@@ -437,14 +438,14 @@ static QStringList metadata( Meta::TrackPtr track )
              (HAS_TAG(album) && title.CONTAINS_TAG(album)) )
         {
             // this will split "all-in-one" filename tags
-            QRegExp rx("(\\s+-\\s+|\\s*;\\s*|\\s*:\\s*)");
+            QRegularExpression rx(QStringLiteral("(\\s+-\\s+|\\s*;\\s*|\\s*:\\s*)"));
             list << title.split( rx, Qt::SkipEmptyParts );
             QList<QString>::iterator i = list.begin();
             bool ok;
             while ( i != list.end() )
             {
                 // check whether this entry is only a number, i.e. probably year or track #
-                i->toInt( &ok );
+                Q_UNUSED( i->toInt( &ok ) );
                 if( ok )
                     i = list.erase( i );
                 else
@@ -558,13 +559,13 @@ MainToolbar::updateBookmarks( const QString *BookmarkName )
             Capabilities::TimecodeLoadCapability *tcl = track->create<Capabilities::TimecodeLoadCapability>();
             BookmarkList list = tcl->loadTimecodes();
             // debug() << "found " << list.count() << " timecodes on this track";
-            foreach( AmarokUrlPtr url, list )
+            for( AmarokUrlPtr url : list )
             {
-                if( url->command() == "play" && url->args().keys().contains( "pos" ) )
+                if( url->command() == QStringLiteral("play") && url->args().keys().contains( QStringLiteral("pos") ) )
                 {
-                    int pos = url->args().value( "pos" ).toDouble() * 1000;
+                    int pos = url->args().value( QStringLiteral("pos") ).toDouble() * 1000;
                     debug() << "showing timecode: " << url->name() << " at " << pos ;
-                    m_slider->drawTriangle( url->name(), pos, ( BookmarkName && BookmarkName == url->name() ) );
+                    m_slider->drawTriangle( url->name(), pos, ( BookmarkName && *BookmarkName == url->name() ) );
                 }
             }
             delete tcl;
@@ -873,7 +874,7 @@ MainToolbar::setLabelTime( int ms )
         int tf = timeFrame( secs );
         if( m_lastTime < 0 || tf != timeFrame( m_lastTime ) )
         {
-            const int w = QFontMetrics( m_timeLabel->font() ).horizontalAdvance( timeString[tf] );
+            const int w = QFontMetrics( m_timeLabel->font() ).horizontalAdvance( QLatin1String(timeString[tf]) );
             m_timeLabel->setFixedWidth( w );
             relayout = true;
         }
@@ -881,11 +882,11 @@ MainToolbar::setLabelTime( int ms )
 
         if( remainingSecs > 0 )
         {
-            m_remainingTimeLabel->setText( '-' + Meta::secToPrettyTime( remainingSecs ) );
+            m_remainingTimeLabel->setText( QLatin1Char('-') + Meta::secToPrettyTime( remainingSecs ) );
             tf = timeFrame( remainingSecs );
             if( m_lastRemainingTime < 0 || tf != timeFrame( m_lastRemainingTime ) )
             {
-                const int w = QFontMetrics( m_remainingTimeLabel->font() ).horizontalAdvance( QStringLiteral("-") + timeString[tf] );
+                const int w = QFontMetrics( m_remainingTimeLabel->font() ).horizontalAdvance( QStringLiteral("-") + QLatin1String(timeString[tf]) );
                 m_remainingTimeLabel->setFixedWidth( w );
                 relayout = true;
             }
