@@ -33,13 +33,16 @@
 #include "core/support/Amarok.h"
 #include "core/support/Debug.h"
 
+#include <KIconLoader>
+#include <KLocalizedString>
+#include <KRatingPainter>
+#include <KWindowSystem>
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+#include <KX11Extras>
+#endif
+
 #include <QApplication>
 #include <QIcon>
-#include <KLocalizedString>
-#include <KWindowSystem>
-#include <KIconLoader>
-#include <KRatingPainter>
-
 #include <QMouseEvent>
 #include <QPainter>
 #include <QPixmap>
@@ -128,7 +131,11 @@ OSDWidget::show()
     {
         QWidget::show();
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         if( windowOpacity() == 0.0 && KWindowSystem::compositingActive() )
+#else
+        if( windowOpacity() == 0.0 && KX11Extras::compositingActive() )
+#endif
         {
             m_fadeTimeLine->setDirection( QTimeLine::Forward );
             m_fadeTimeLine->start();
@@ -145,7 +152,11 @@ OSDWidget::show()
 void
 OSDWidget::hide()
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if( KWindowSystem::compositingActive() )
+#else
+    if( KX11Extras::compositingActive() )
+#endif
     {
         m_fadeTimeLine->setDirection( QTimeLine::Backward );
         m_fadeTimeLine->start();
