@@ -40,7 +40,7 @@ TestM3UPlaylist::TestM3UPlaylist()
 QString
 TestM3UPlaylist::dataPath( const QString &relPath )
 {
-    return QDir::toNativeSeparators( QString( AMAROK_TEST_DIR ) + '/' + relPath );
+    return QDir::toNativeSeparators( QStringLiteral( AMAROK_TEST_DIR ) + QLatin1Char('/') + relPath );
 }
 
 void TestM3UPlaylist::initTestCase()
@@ -55,11 +55,11 @@ void TestM3UPlaylist::initTestCase()
      * Pre-create it explicitly */
     CollectionManager::instance();
 
-    const QUrl url = QUrl::fromLocalFile(dataPath( "data/playlists/test.m3u" ));
+    const QUrl url = QUrl::fromLocalFile(dataPath( QStringLiteral("data/playlists/test2.m3u") ));
     QFile playlistFile1( url.toLocalFile() );
     QTextStream playlistStream;
 
-    QString tempPath = m_tempDir->path() + "/test.m3u";
+    QString tempPath = m_tempDir->path() + QStringLiteral("/test.m3u");
     QVERIFY( QFile::copy( url.toLocalFile(), tempPath ) );
     QVERIFY( QFile::exists( tempPath ) );
 
@@ -70,7 +70,7 @@ void TestM3UPlaylist::initTestCase()
     m_testPlaylist = new Playlists::M3UPlaylist( QUrl::fromLocalFile(tempPath) );
     QVERIFY( m_testPlaylist );
     QVERIFY( m_testPlaylist->load( playlistStream ) );
-    QCOMPARE( m_testPlaylist->tracks().size(), 10 );
+    QCOMPARE( m_testPlaylist->tracks().size(), 11 );
     playlistFile1.close();
 }
 
@@ -85,37 +85,38 @@ void TestM3UPlaylist::cleanupTestCase()
 
 void TestM3UPlaylist::testSetAndGetName()
 {
-    QCOMPARE( m_testPlaylist->prettyName(), QString( "test.m3u" ) );
+    QCOMPARE( m_testPlaylist->prettyName(), QStringLiteral( "test.m3u" ) );
 
-    QCOMPARE( m_testPlaylist->name(), QString( "test.m3u" ) );
+    QCOMPARE( m_testPlaylist->name(), QStringLiteral( "test.m3u" ) );
 
-    m_testPlaylist->setName( "set name test" );
-    QCOMPARE( m_testPlaylist->name(), QString( "set name test.m3u" ) );
+    m_testPlaylist->setName( QStringLiteral("set name test") );
+    QCOMPARE( m_testPlaylist->name(), QStringLiteral( "set name test.m3u" ) );
 
-    m_testPlaylist->setName( "set name test aäoöuüß.m3u" );
-    QCOMPARE( m_testPlaylist->name(), QString( "set name test aäoöuüß.m3u" ) );
+    m_testPlaylist->setName( QStringLiteral("set name test aäoöuüß.m3u") );
+    QCOMPARE( m_testPlaylist->name(), QStringLiteral( "set name test aäoöuüß.m3u" ) );
 
-    m_testPlaylist->setName( "test" );
-    m_testPlaylist->setName( "" );
-    QCOMPARE( m_testPlaylist->name(), QString( "test.m3u" ) );
+    m_testPlaylist->setName( QStringLiteral("test") );
+    m_testPlaylist->setName( QStringLiteral("") );
+    QCOMPARE( m_testPlaylist->name(), QStringLiteral( "test.m3u" ) );
 }
 
 void TestM3UPlaylist::testTracks()
 {
     Meta::TrackList tracklist = m_testPlaylist->tracks();
 
-    QCOMPARE( tracklist.size(), 10 );
-    QCOMPARE( tracklist.at( 0 )->name(), QString( "Platz 01" ) );
-    QCOMPARE( tracklist.at( 1 )->name(), QString( "Platz 02" ) );
-    QCOMPARE( tracklist.at( 2 )->name(), QString( "Platz 03" ) );
-    QCOMPARE( tracklist.at( 9 )->name(), QString( "Platz 10" ) );
+    QCOMPARE( tracklist.size(), 11 );
+    QCOMPARE( tracklist.at( 0 )->name(), QStringLiteral( "Platz 01" ) );
+    QCOMPARE( tracklist.at( 1 )->name(), QStringLiteral( "Platz 02" ) );
+    QCOMPARE( tracklist.at( 2 )->name(), QStringLiteral( "Platz 03" ) );
+    QCOMPARE( tracklist.at( 9 )->name(), QStringLiteral( "Platz 10" ) );
+    QCOMPARE( tracklist.at( 10 )->name(), QStringLiteral( "Plätz 11" ) );
 }
 
 void TestM3UPlaylist::testUidUrl()
 {
-    QString tempPath = m_tempDir->path() + "/test.m3u";
+    QString tempPath = m_tempDir->path() + QStringLiteral("/test.m3u");
     //we have changed the name around so much, better reset it
-    m_testPlaylist->setName( "test" );
+    m_testPlaylist->setName( QStringLiteral("test") );
     QCOMPARE( m_testPlaylist->uidUrl().toLocalFile(), tempPath );
 }
 
@@ -127,11 +128,11 @@ void TestM3UPlaylist::testSetAndGetGroups()
     grouplist = m_testPlaylist->groups();
     QCOMPARE( grouplist.size(), 0 );
 
-    newGrouplist.append( "test" );
+    newGrouplist.append( QStringLiteral("test") );
     m_testPlaylist->setGroups( newGrouplist );
     grouplist = m_testPlaylist->groups();
     QCOMPARE( grouplist.size(), 1 );
-    QCOMPARE( grouplist.at(0), QString( "test" ) );
+    QCOMPARE( grouplist.at(0), QStringLiteral( "test" ) );
 }
 
 void TestM3UPlaylist::testIsWritable()
@@ -143,3 +144,33 @@ void TestM3UPlaylist::testSave()
 {
     QVERIFY( m_testPlaylist->save( false ) );
 }
+
+void TestM3UPlaylist::testSaveAndReload()
+{
+    QVERIFY( m_testPlaylist->save( false ) );
+    Meta::TrackList tracklist = m_testPlaylist->tracks();
+    const QString testTrack1Url = tracklist.at( 1 )->uidUrl();
+    const QString testTrack2Url = tracklist.at( 10 )->uidUrl();
+
+    const QUrl url = m_testPlaylist->uidUrl();
+    QFile playlistFile1( url.toLocalFile() );
+    QTextStream playlistStream;
+
+    QVERIFY( playlistFile1.open( QFile::ReadOnly ) );
+    playlistStream.setDevice( &playlistFile1 );
+    QVERIFY( playlistStream.device() );
+
+    delete m_testPlaylist;
+    m_testPlaylist = new Playlists::M3UPlaylist( url );
+    QVERIFY( m_testPlaylist );
+    QVERIFY( m_testPlaylist->load( playlistStream ) );
+    playlistFile1.close();
+
+    tracklist = m_testPlaylist->tracks();
+
+    QCOMPARE( tracklist.size(), 11 );
+    QCOMPARE( tracklist.at( 9 )->name(), QStringLiteral( "Platz 10" ) );
+    QCOMPARE( tracklist.at( 10 )->name(), QStringLiteral( "Plätz 11" ) );
+    QCOMPARE( tracklist.at( 1 )->uidUrl(), testTrack1Url );
+    QCOMPARE( tracklist.at( 10 )->uidUrl(), testTrack2Url );
+}
