@@ -42,7 +42,7 @@ TestXSPFPlaylist::TestXSPFPlaylist()
 QString
 TestXSPFPlaylist::dataPath( const QString &relPath )
 {
-    return QDir::toNativeSeparators( QString( AMAROK_TEST_DIR ) + '/' + relPath );
+    return QDir::toNativeSeparators( QStringLiteral( AMAROK_TEST_DIR ) + QLatin1Char('/') + relPath );
 }
 
 
@@ -60,7 +60,7 @@ void TestXSPFPlaylist::initTestCase()
      * Pre-create it explicitly */
     CollectionManager::instance();
 
-    const QString testXspf = "data/playlists/test.xspf";
+    const QString testXspf = QStringLiteral("data/playlists/test2.xspf");
     const QUrl url = QUrl::fromLocalFile(dataPath( testXspf ));
     QFile playlistFile1( url.toLocalFile() );
     QTextStream playlistStream1;
@@ -74,7 +74,7 @@ void TestXSPFPlaylist::initTestCase()
     //we need to copy this playlist file to a temp dir as some of the tests we do will delete/overwrite it
     m_tempDir = new QTemporaryDir;;
     QVERIFY( m_tempDir->isValid() );
-    QString tempPath = m_tempDir->path() + "/test.xspf";
+    QString tempPath = m_tempDir->path() + QStringLiteral("/test.xspf");
     qDebug() << "got temp path: " << tempPath;
     QVERIFY( QFile::copy( url.toLocalFile(), tempPath ) );
     QVERIFY( QFile::exists( tempPath ) );
@@ -86,7 +86,7 @@ void TestXSPFPlaylist::initTestCase()
 
 void TestXSPFPlaylist::cleanupTestCase()
 {
-    QFile::remove( QStandardPaths::locate( QStandardPaths::TempLocation, "test.xspf" ) );
+    QFile::remove( QStandardPaths::locate( QStandardPaths::TempLocation, QStringLiteral("test.xspf") ) );
     // Wait for other jobs, like MetaProxys fetching meta data, to finish
     ThreadWeaver::Queue::instance()->finish();
 
@@ -97,158 +97,159 @@ void TestXSPFPlaylist::cleanupTestCase()
 
 void TestXSPFPlaylist::testSetAndGetName()
 {
-    QCOMPARE( m_testPlaylist1->name(), QString( "my playlist" ) );
+    QCOMPARE( m_testPlaylist1->name(), QStringLiteral( "my playlist" ) );
 
-    m_testPlaylist1->setName( "test" );
-    QCOMPARE( m_testPlaylist1->name(), QString( "test" ) );
+    m_testPlaylist1->setName( QStringLiteral("test") );
+    QCOMPARE( m_testPlaylist1->name(), QStringLiteral( "test" ) );
 
-    m_testPlaylist1->setName( "test aäoöuüß" );
-    QCOMPARE( m_testPlaylist1->name(), QString( "test aäoöuüß" ) );
+    m_testPlaylist1->setName( QStringLiteral("test aäoöuüß") );
+    QCOMPARE( m_testPlaylist1->name(), QStringLiteral( "test aäoöuüß" ) );
 
-    m_testPlaylist1->setName( "" );
-    QCOMPARE( m_testPlaylist1->name(), QString( "" ) );
+    m_testPlaylist1->setName( QStringLiteral("") );
+    QCOMPARE( m_testPlaylist1->name(), QStringLiteral( "" ) );
 }
 
 void TestXSPFPlaylist::prettyName()
 {
-    QCOMPARE( m_testPlaylist1->prettyName(), QString( "" ) );
+    QCOMPARE( m_testPlaylist1->prettyName(), QStringLiteral( "" ) );
 }
 
 void TestXSPFPlaylist::testSetAndGetTracks()
 {
     Meta::TrackList tracklist = m_testPlaylist1->tracks();
 
-    QCOMPARE( tracklist.size(), 23 );
-    QCOMPARE( tracklist.at( 0 )->name(), QString( "Sunset" ) );
-    QCOMPARE( tracklist.at( 1 )->name(), QString( "Heaven" ) );
-    QCOMPARE( tracklist.at( 2 )->name(), QString( "Liquid Sun" ) );
-    QCOMPARE( tracklist.at( 3 )->name(), QString( "Restrained Mind" ) );
-    QCOMPARE( tracklist.at( 22 )->name(), QString( "Trash Bag" ) );
+    QCOMPARE( tracklist.size(), 24 );
+    QCOMPARE( tracklist.at( 0 )->name(), QStringLiteral( "Sunset" ) );
+    QCOMPARE( tracklist.at( 1 )->name(), QStringLiteral( "Heaven" ) );
+    QCOMPARE( tracklist.at( 2 )->name(), QStringLiteral( "Liquid Sun" ) );
+    QCOMPARE( tracklist.at( 3 )->name(), QStringLiteral( "Restrained Mind" ) );
+    QCOMPARE( tracklist.at( 22 )->name(), QStringLiteral( "Trash Bag" ) );
+    QCOMPARE( tracklist.at( 23 )->name(), QStringLiteral( "Test träck" ) );
 }
 
 void TestXSPFPlaylist::testSetAndGetTitle()
 {
-    QCOMPARE( m_testPlaylist1->title(), QString( "" ) );
+    QCOMPARE( m_testPlaylist1->title(), QStringLiteral( "" ) );
 
-    m_testPlaylist1->setTitle( "test" );
-    QCOMPARE( m_testPlaylist1->title(), QString( "test" ) );
+    m_testPlaylist1->setTitle( QStringLiteral("test") );
+    QCOMPARE( m_testPlaylist1->title(), QStringLiteral( "test" ) );
 
-    m_testPlaylist1->setTitle( "test aäoöuüß" );
-    QCOMPARE( m_testPlaylist1->title(), QString( "test aäoöuüß" ) );
+    m_testPlaylist1->setTitle( QStringLiteral("test aäoöuüß") );
+    QCOMPARE( m_testPlaylist1->title(), QStringLiteral( "test aäoöuüß" ) );
 
-    m_testPlaylist1->setTitle( "" );
-    QCOMPARE( m_testPlaylist1->title(), QString( "" ) );
+    m_testPlaylist1->setTitle( QStringLiteral("") );
+    QCOMPARE( m_testPlaylist1->title(), QStringLiteral( "" ) );
 }
 
 void TestXSPFPlaylist::testSetAndGetCreator()
 {
-    QCOMPARE( m_testPlaylist1->creator(), QString( "" ) );
+    QCOMPARE( m_testPlaylist1->creator(), QStringLiteral( "" ) );
 
-    m_testPlaylist1->setCreator( "test" );
-    QCOMPARE( m_testPlaylist1->creator(), QString( "test" ) );
+    m_testPlaylist1->setCreator( QStringLiteral("test") );
+    QCOMPARE( m_testPlaylist1->creator(), QStringLiteral( "test" ) );
 
-    m_testPlaylist1->setCreator( "test aäoöuüß" );
-    QCOMPARE( m_testPlaylist1->creator(), QString( "test aäoöuüß" ) );
+    m_testPlaylist1->setCreator( QStringLiteral("test aäoöuüß") );
+    QCOMPARE( m_testPlaylist1->creator(), QStringLiteral( "test aäoöuüß" ) );
 
-    m_testPlaylist1->setCreator( "" );
-    QCOMPARE( m_testPlaylist1->creator(), QString( "" ) );
+    m_testPlaylist1->setCreator( QStringLiteral("") );
+    QCOMPARE( m_testPlaylist1->creator(), QStringLiteral( "" ) );
 }
 
 void TestXSPFPlaylist::testSetAndGetAnnotation()
 {
-    QCOMPARE( m_testPlaylist1->annotation(), QString( "" ) );
+    QCOMPARE( m_testPlaylist1->annotation(), QStringLiteral( "" ) );
 
-    m_testPlaylist1->setAnnotation( "test" );
-    QCOMPARE( m_testPlaylist1->annotation(), QString( "test" ) );
+    m_testPlaylist1->setAnnotation( QStringLiteral("test") );
+    QCOMPARE( m_testPlaylist1->annotation(), QStringLiteral( "test" ) );
 
-    m_testPlaylist1->setAnnotation( "test aäoöuüß" );
-    QCOMPARE( m_testPlaylist1->annotation(), QString( "test aäoöuüß" ) );
+    m_testPlaylist1->setAnnotation( QStringLiteral("test aäoöuüß") );
+    QCOMPARE( m_testPlaylist1->annotation(), QStringLiteral( "test aäoöuüß" ) );
 
-    m_testPlaylist1->setAnnotation( "" );
-    QCOMPARE( m_testPlaylist1->annotation(), QString( "" ) );
+    m_testPlaylist1->setAnnotation( QStringLiteral("") );
+    QCOMPARE( m_testPlaylist1->annotation(), QStringLiteral( "" ) );
 }
 
 void TestXSPFPlaylist::testSetAndGetInfo()
 {
     QUrl testUrl;
 
-    QCOMPARE( m_testPlaylist1->info(), QUrl( "" ) );
+    QCOMPARE( m_testPlaylist1->info(), QUrl( QStringLiteral("") ) );
 
-    testUrl = QUrl::fromUserInput("http://amarok.kde.org");
+    testUrl = QUrl::fromUserInput(QStringLiteral("http://amarok.kde.org"));
     m_testPlaylist1->setInfo( testUrl );
     QCOMPARE( m_testPlaylist1->info(), QUrl( testUrl ) );
 
-    testUrl = QUrl::fromUserInput("http://öko.de");
+    testUrl = QUrl::fromUserInput(QStringLiteral("http://öko.de"));
     m_testPlaylist1->setInfo( testUrl );
     QCOMPARE( m_testPlaylist1->info(), QUrl( testUrl ) );
 
-    testUrl = QUrl::fromUserInput("");
+    testUrl = QUrl::fromUserInput(QStringLiteral(""));
     m_testPlaylist1->setInfo( testUrl );
-    QCOMPARE( m_testPlaylist1->info(), QUrl( "" ) );
+    QCOMPARE( m_testPlaylist1->info(), QUrl( QStringLiteral("") ) );
 }
 
 void TestXSPFPlaylist::testSetAndGetLocation()
 {
     QUrl testUrl;
 
-    QCOMPARE( m_testPlaylist1->location(), QUrl( "" ) );
+    QCOMPARE( m_testPlaylist1->location(), QUrl( QStringLiteral("") ) );
 
-    testUrl = QUrl::fromUserInput("http://amarok.kde.org");
+    testUrl = QUrl::fromUserInput(QStringLiteral("http://amarok.kde.org"));
     m_testPlaylist1->setLocation( testUrl );
     QCOMPARE( m_testPlaylist1->location(), QUrl( testUrl ) );
 
-    testUrl = QUrl::fromUserInput("http://öko.de");
+    testUrl = QUrl::fromUserInput(QStringLiteral("http://öko.de"));
     m_testPlaylist1->setLocation( testUrl );
     QCOMPARE( m_testPlaylist1->location(), QUrl( testUrl ) );
 
-    testUrl = QUrl::fromUserInput("");
+    testUrl = QUrl::fromUserInput(QStringLiteral(""));
     m_testPlaylist1->setLocation( testUrl );
-    QCOMPARE( m_testPlaylist1->location(), QUrl( "" ) );
+    QCOMPARE( m_testPlaylist1->location(), QUrl( QStringLiteral("") ) );
 }
 
 void TestXSPFPlaylist::testSetAndGetIdentifier()
 {
-    QCOMPARE( m_testPlaylist1->identifier(), QString( "" ) );
+    QCOMPARE( m_testPlaylist1->identifier(), QStringLiteral( "" ) );
 
-    m_testPlaylist1->setIdentifier( "test" );
-    QCOMPARE( m_testPlaylist1->identifier(), QString( "test" ) );
+    m_testPlaylist1->setIdentifier( QStringLiteral("test") );
+    QCOMPARE( m_testPlaylist1->identifier(), QStringLiteral( "test" ) );
 
-    m_testPlaylist1->setIdentifier( "test aäoöuüß" );
-    QCOMPARE( m_testPlaylist1->identifier(), QString( "test aäoöuüß" ) );
+    m_testPlaylist1->setIdentifier( QStringLiteral("test aäoöuüß") );
+    QCOMPARE( m_testPlaylist1->identifier(), QStringLiteral( "test aäoöuüß" ) );
 
-    m_testPlaylist1->setIdentifier( "" );
-    QCOMPARE( m_testPlaylist1->identifier(), QString( "" ) );
+    m_testPlaylist1->setIdentifier( QStringLiteral("") );
+    QCOMPARE( m_testPlaylist1->identifier(), QStringLiteral( "" ) );
 }
 
 void TestXSPFPlaylist::testSetAndGetImage()
 {
     QUrl testUrl;
 
-    QCOMPARE( m_testPlaylist1->image(), QUrl( "" ) );
+    QCOMPARE( m_testPlaylist1->image(), QUrl( QStringLiteral("") ) );
 
-    testUrl = QUrl::fromUserInput("http://amarok.kde.org");
+    testUrl = QUrl::fromUserInput(QStringLiteral("http://amarok.kde.org"));
     m_testPlaylist1->setImage( testUrl );
     QCOMPARE( m_testPlaylist1->image(), QUrl( testUrl ) );
 
-    testUrl = QUrl::fromUserInput("http://öko.de");
+    testUrl = QUrl::fromUserInput(QStringLiteral("http://öko.de"));
     m_testPlaylist1->setImage( testUrl );
     QCOMPARE( m_testPlaylist1->image(), QUrl( testUrl ) );
 
-    testUrl = QUrl::fromUserInput("");
+    testUrl = QUrl::fromUserInput(QStringLiteral(""));
     m_testPlaylist1->setImage( testUrl );
-    QCOMPARE( m_testPlaylist1->image(), QUrl( "" ) );
+    QCOMPARE( m_testPlaylist1->image(), QUrl( QStringLiteral("") ) );
 }
 
 void TestXSPFPlaylist::testSetAndGetDate()
 {
     QDateTime testDateTime;
-    QCOMPARE( m_testPlaylist1->date().toString(), QString( "" ) );
+    QCOMPARE( m_testPlaylist1->date().toString(), QStringLiteral( "" ) );
 
-    testDateTime = QDateTime::fromString( "2009/08/13 13:57:18", "yyyy/MM/dd hh:mm:ss" );
+    testDateTime = QDateTime::fromString( QStringLiteral("2009/08/13 13:57:18"), QStringLiteral("yyyy/MM/dd hh:mm:ss") );
     m_testPlaylist1->setDate( testDateTime );
     QCOMPARE( m_testPlaylist1->date(), testDateTime );
 
-    testDateTime = QDateTime::fromString( "", "" );
+    testDateTime = QDateTime::fromString( QStringLiteral(""), QStringLiteral("") );
     m_testPlaylist1->setDate( testDateTime );
     QCOMPARE( m_testPlaylist1->date(), testDateTime );
 }
@@ -257,19 +258,19 @@ void TestXSPFPlaylist::testSetAndGetLicense()
 {
     QUrl testUrl;
 
-    QCOMPARE( m_testPlaylist1->license(), QUrl( "" ) );
+    QCOMPARE( m_testPlaylist1->license(), QUrl( QStringLiteral("") ) );
 
-    testUrl = QUrl::fromUserInput("http://amarok.kde.org");
+    testUrl = QUrl::fromUserInput(QStringLiteral("http://amarok.kde.org"));
     m_testPlaylist1->setLicense( testUrl );
     QCOMPARE( m_testPlaylist1->license(), QUrl( testUrl ) );
 
-    testUrl = QUrl::fromUserInput("http://öko.de");
+    testUrl = QUrl::fromUserInput(QStringLiteral("http://öko.de"));
     m_testPlaylist1->setLicense( testUrl );
     QCOMPARE( m_testPlaylist1->license(), QUrl( testUrl ) );
 
-    testUrl = QUrl::fromUserInput("");
+    testUrl = QUrl::fromUserInput(QStringLiteral(""));
     m_testPlaylist1->setLicense( testUrl );
-    QCOMPARE( m_testPlaylist1->license(), QUrl( "" ) );
+    QCOMPARE( m_testPlaylist1->license(), QUrl( QStringLiteral("") ) );
 }
 
 void TestXSPFPlaylist::testSetAndGetAttribution()
@@ -278,23 +279,23 @@ void TestXSPFPlaylist::testSetAndGetAttribution()
 
     QCOMPARE( m_testPlaylist1->attribution().size(), 0 );
 
-    testUrl = QUrl::fromUserInput("http://amarok.kde.org");
+    testUrl = QUrl::fromUserInput(QStringLiteral("http://amarok.kde.org"));
     m_testPlaylist1->setAttribution( testUrl );
     QCOMPARE( m_testPlaylist1->attribution().size(), 1 );
     QCOMPARE( m_testPlaylist1->attribution().at( 0 ), QUrl( testUrl ) );
 
-    testUrl = QUrl::fromUserInput("http://öko.de");
+    testUrl = QUrl::fromUserInput(QStringLiteral("http://öko.de"));
     m_testPlaylist1->setAttribution( testUrl );
     QCOMPARE( m_testPlaylist1->attribution().size(), 2 );
     QCOMPARE( m_testPlaylist1->attribution().at( 0 ), QUrl( testUrl ) );
-    QCOMPARE( m_testPlaylist1->attribution().at( 1 ), QUrl("http://amarok.kde.org") );
+    QCOMPARE( m_testPlaylist1->attribution().at( 1 ), QUrl(QStringLiteral("http://amarok.kde.org")) );
 
-    testUrl = QUrl::fromUserInput("http://test.com");
+    testUrl = QUrl::fromUserInput(QStringLiteral("http://test.com"));
     m_testPlaylist1->setAttribution( testUrl, false );
     QCOMPARE( m_testPlaylist1->attribution().size(), 1 );
     QCOMPARE( m_testPlaylist1->attribution().at( 0 ), QUrl( testUrl ) );
 
-    testUrl = QUrl::fromUserInput("");
+    testUrl = QUrl::fromUserInput(QStringLiteral(""));
     m_testPlaylist1->setAttribution( testUrl );
     QCOMPARE( m_testPlaylist1->attribution().size(), 1 ); // empty url won't be added, but size is 1 from last addition
 }
@@ -303,27 +304,27 @@ void TestXSPFPlaylist::testSetAndGetLink()
 {
     QUrl testUrl;
 
-    QCOMPARE( m_testPlaylist1->link(), QUrl( "" ) );
+    QCOMPARE( m_testPlaylist1->link(), QUrl( QStringLiteral("") ) );
 
-    testUrl = QUrl::fromUserInput("http://amarok.kde.org");
+    testUrl = QUrl::fromUserInput(QStringLiteral("http://amarok.kde.org"));
     m_testPlaylist1->setLink( testUrl );
     QCOMPARE( m_testPlaylist1->link(), QUrl( testUrl ) );
 
-    testUrl = QUrl::fromUserInput("http://öko.de");
+    testUrl = QUrl::fromUserInput(QStringLiteral("http://öko.de"));
     m_testPlaylist1->setLink( testUrl );
     QCOMPARE( m_testPlaylist1->link(), QUrl( testUrl ) );
 
-    testUrl = QUrl::fromUserInput("");
+    testUrl = QUrl::fromUserInput(QStringLiteral(""));
     m_testPlaylist1->setLink( testUrl );
-    QCOMPARE( m_testPlaylist1->link(), QUrl( "" ) );
+    QCOMPARE( m_testPlaylist1->link(), QUrl( QStringLiteral("") ) );
 }
 
 void TestXSPFPlaylist::testUidUrl()
 {
-    QString tempPath = m_tempDir->path() + "/test.xspf";
+    QString tempPath = m_tempDir->path() + QStringLiteral("/test.xspf");
 
     //we have changed the name around so much, better reset it
-    m_testPlaylist1->setName( "test" );
+    m_testPlaylist1->setName( QStringLiteral("test") );
     QCOMPARE( m_testPlaylist1->uidUrl().toLocalFile(), tempPath );
 }
 
@@ -336,3 +337,34 @@ void TestXSPFPlaylist::testSave()
 {
     QVERIFY( m_testPlaylist1->save( false ) );
 }
+
+void TestXSPFPlaylist::testSaveAndReload()
+{
+    QVERIFY( m_testPlaylist1->save( false ) );
+
+    Meta::TrackList tracklist = m_testPlaylist1->tracks();
+    const QString testTrack1Url = tracklist.at( 1 )->uidUrl();
+    const QString testTrack2Url = tracklist.at( 23 )->uidUrl();
+
+    const QUrl url = m_testPlaylist1->uidUrl();
+    QFile playlistFile1( url.toLocalFile() );
+    QTextStream playlistStream;
+
+    QVERIFY( playlistFile1.open( QFile::ReadOnly ) );
+    playlistStream.setDevice( &playlistFile1 );
+    QVERIFY( playlistStream.device() );
+
+    delete m_testPlaylist1;
+    m_testPlaylist1 = new Playlists::XSPFPlaylist( url );
+    QVERIFY( m_testPlaylist1 );
+    QVERIFY( m_testPlaylist1->load( playlistStream ) );
+    playlistFile1.close();
+
+    tracklist = m_testPlaylist1->tracks();
+
+    QCOMPARE( tracklist.size(), 24 );
+    QCOMPARE( tracklist.at( 0 )->name(), QStringLiteral( "Sunset" ) );
+    QCOMPARE( tracklist.at( 23 )->name(), QStringLiteral( "Test träck" ) );
+    QCOMPARE( tracklist.at( 1 )->uidUrl(), testTrack1Url );
+    QCOMPARE( tracklist.at( 23 )->uidUrl(), testTrack2Url );
+}
